From 1bd388d808de32139d2a642d68d55793a22cbc48 Mon Sep 17 00:00:00 2001
From: Jeffrey Cody <jcody@redhat.com>
Date: Wed, 26 Apr 2017 20:08:50 +0200
Subject: [PATCH 04/11] block: honor BDRV_O_ALLOW_RDWR when clearing
 bs->read_only

RH-Author: Jeffrey Cody <jcody@redhat.com>
Message-id: <7b5c2f86cb3988c2365e53d47d54d469dcb5ab2f.1493236824.git.jcody@redhat.com>
Patchwork-id: 74898
O-Subject: [RHEV-7.4 qemu-kvm-rhev 3/8] block: honor BDRV_O_ALLOW_RDWR when clearing bs->read_only
Bugzilla: 1189998
RH-Acked-by: John Snow <jsnow@redhat.com>
RH-Acked-by: Stefan Hajnoczi <stefanha@redhat.com>
RH-Acked-by: Max Reitz <mreitz@redhat.com>

The BDRV_O_ALLOW_RDWR flag allows / prohibits the changing of
the BDS 'read_only' state, but there are a few places where it
is ignored.  In the bdrv_set_read_only() helper, make sure to
honor the flag.

Signed-off-by: Jeff Cody <jcody@redhat.com>
Reviewed-by: Stefan Hajnoczi <stefanha@redhat.com>
Reviewed-by: John Snow <jsnow@redhat.com>
Message-id: be2e5fb2d285cbece2b6d06bed54a6f56520d251.1491597120.git.jcody@redhat.com
(cherry picked from commit d6fcdf06d9fc7d72151cc2069dc5c1adf5c21707)
Signed-off-by: Miroslav Rezanina <mrezanin@redhat.com>
---
 block.c | 7 +++++++
 1 file changed, 7 insertions(+)

diff --git a/block.c b/block.c
index 4766b8a..b74d445 100644
--- a/block.c
+++ b/block.c
@@ -201,6 +201,13 @@ int bdrv_set_read_only(BlockDriverState *bs, bool read_only, Error **errp)
         return -EINVAL;
     }
 
+    /* Do not clear read_only if it is prohibited */
+    if (!read_only && !(bs->open_flags & BDRV_O_ALLOW_RDWR)) {
+        error_setg(errp, "Node '%s' is read only",
+                   bdrv_get_device_or_node_name(bs));
+        return -EPERM;
+    }
+
     bs->read_only = read_only;
     return 0;
 }
-- 
1.8.3.1

